import pygame

from OpenGL.GL import *
from OpenGL.GLU import *
from pygame.locals import *

import menu
import data
import world
import texturebox
import animationbox
import tileset
import font

import spider

class Game:

	def __init__(self):
		# Initialize pygame
		pygame.init()
		pygame.display.set_mode((800,600),pygame.OPENGL|pygame.DOUBLEBUF)
	#	pygame.display.toggle_fullscreen()
		# Create containers for game data
		self.tBox = texturebox.TextureBox()
		self.aBox = animationbox.AnimationBox(self.tBox) 
#		self.mbox = musicbox.MusicBox()		
#		self.sbox = soundbox.SoundBox() 
		try:
			pygame.mixer.music.load("music.ogg")
			pygame.mixer.music.play(-1)
		except pygame.error:
			pass
			
		
		print "Loading textures"
		data.loadTextures(self.tBox)
		print "Loading animation textures"
		data.loadAnimations(self.aBox)
		print "Loading music"
#		data.loadMusic(self.mBox)	
		print "Loading sounds"
#		data.loadSounds(self.sbox)
		
		# Setup OpenGL stuff
		glMatrixMode(GL_PROJECTION)
		glLoadIdentity()
		glOrtho(-8,8,-6,6,-1000,1000)
		glTranslatef(0,0,-10)
		glMatrixMode(GL_MODELVIEW)
		glLoadIdentity()
		glEnable(GL_TEXTURE_2D)
		glDepthRange(1,-100)
#		self.backdlist = glGenLists(1)
#		self.frontdlist = glGenLists(1)
		glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA)
		glEnable(GL_BLEND)
	
		# Create clock
		self.clock = pygame.time.Clock()

		# Generate world
		self.world = world.World(self.tBox,self.aBox)

	#	joy = pygame.joystick.Joystick(0)
	#	joy.init()
	#	self.joy = joy
		# Player vector
		self.xv = 0
		self.yv = 0
	
		self.font = font.Font(self.tBox.get("charmap")) 
		self.wstring = " _______\n" + "< w00t! >\n" + " -------\n" + "        \\   ^__^\n" + "         \\  (oo)\\_______\n" + "            (__)\\       )\\/\\\n" + "                ||----w |\n" + "                ||     ||" 

	def run(self):
		i = 0
		posx=0
		posy=0
		done = False	
		self.clock.tick()
		fps=0
		showMenu = False
		releasedMenuButton = True
		while not done:
			actionButton = False
			action = None	
			### Check input
			for event in pygame.event.get():
				if event.type == KEYDOWN:
						if event.key == K_ESCAPE:
							done = True
						elif event.key == QUIT:
							done = True
						elif event.key == K_LEFT:
							self.xv = -1
						elif event.key == K_RIGHT:
							self.xv = 1
						elif event.key == K_UP:
							self.yv = 1
						elif event.key == K_DOWN:
							self.yv = -1
						elif event.key == K_LCTRL:
							actionButton = True	
						elif event.key == K_SPACE:
							if showMenu == True:
								showMenu = False	
							else:
								showMenu = True	
						
				elif event.type == KEYUP:
						if event.key == K_LEFT:
							if self.xv == -1:
								self.xv = 0 
						elif event.key == K_RIGHT:
							if self.xv == 1:
								self.xv = 0
						elif event.key == K_UP:
							if self.yv == 1:
								self.yv = 0
						elif event.key == K_DOWN:
							if self.yv == -1:
								self.yv = 0




			#pygame.event.pump()
			#posx+= 0.1*self.joy.get_axis(0)
			#posy-= 0.1*self.joy.get_axis(1)

			# Update clock
			timeDelta = self.clock.tick()

			glPushMatrix()
			self.world.useItem = False
			# Update menu
			if showMenu:
				if not self.world.imenu.enabled:
					self.world.imenu.enable()

				self.world.imenu.update(timeDelta)
				if actionButton and self.world.imenu.isDone():
					self.world.imenu.select()
					self.world.useItem = True
					action = 'useitem'
					self.world.imenu.disable()	
					showMenu = False
				elif self.xv == -1:
					self.world.imenu.previous()
				elif self.xv == 1:
					self.world.imenu.next()

			elif actionButton:
				action='shot'
				actionButton = False

			### Update world
			if not showMenu:
				self.world.update(self.xv,self.yv,action,timeDelta)
		#		print action

			# self.world.update()

			### Draw stuff

			# Clear screen
			glClear(GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT)
			#glColor4d(1,1,1,0.5)	
			# Save 2d view

			self.world.render()
			# Clear depth buffer (2d stuff doesn't work correctly otherwise)
		#	glClear(GL_DEPTH_BUFFER_BIT)

			# Render menu
			if showMenu:
				self.world.imenu.render()
				if not self.world.imenu.enabled:
					showMenu = False
			

		#	glColor3d(1,1,0)
			fstr,fyp,fxp,fw,fh,cs,ls = self.world.printString
			self.font.renderString(fstr,fyp,fxp,fw,fh,cs,ls)
		#	glColor3d(1,1,1)
			self.font.renderString('fps:' + str(int(round(fps))) ,5,-5,0.5,0.5,0.3,0.3)
		#	glColor3d(1,1,1)

			glPopMatrix()
			# Flush pipline
			glFlush()

		#	sur = self.font.render("Test", True, (255,255,255))
			#self.surf.blit(sur,(10,10))

			# Flip screen
			pygame.display.flip()
			
			
			fps = self.clock.get_fps()
		#		self.menu.next()

		#j	if(i%500 ==0):
		#j		done = True


g = Game()
g.run()
pygame.quit()
